bearermanagement/mpm/inc/mpmserver.h
branchRCL_3
changeset 15 4dc3bb0099b0
parent 8 2e6c4614c58e
child 17 c14618f9de99
--- a/bearermanagement/mpm/inc/mpmserver.h	Mon Mar 15 12:42:11 2010 +0200
+++ b/bearermanagement/mpm/inc/mpmserver.h	Wed Mar 31 22:15:10 2010 +0300
@@ -125,7 +125,8 @@
 // Which component initiated sending preferred IAP notifications
 enum TPrefIAPNotifCaller
     {
-    EConnMon = 0, 
+    EConnMon = 0,
+    EConnMonEvent,
     EBearerMan, 
     EConfirmDlgRoaming, 
     EConfirmDlgStarting
@@ -342,8 +343,10 @@
         * Checks if the connection is started for the Iap Id.
         * @since 3.2
         * @param aIapId IAP Id of the connection
+        * @param aConnId Connection Id
         */
-        TBool CheckIfStarted( const TUint32 aIapId );
+        TBool CheckIfStarted( const TUint32 aIapId, 
+                              const TConnectionId aConnId );
 
         /**
         * Checks if a connection is started with wlan iap.
@@ -437,9 +440,11 @@
         /**
         * Notify each session about IAP availability change.
         * @since 3.1
         * @param aIapInfo Info about available IAPs 
         */
-        void NotifyBMPrefIapL( const TConnMonIapInfo& aIapInfo );
+        void NotifyBMPrefIapL( const TConnMonIapInfo& aIapInfo,
+                               const TPrefIAPNotifCaller aCaller );
 
         /**
         * Update Connection dialog of each session
@@ -489,17 +494,6 @@
         /**
         * Handling of unblacklisting all IAPs for certain category.
         * @since 3.2
-        * @param aConnId Connection Id
-        * @param aCategory Either connection lifetime or temporary. 
-        * @return KErrNone if successful, otherwise one of the
-        * system-wide error codes 
-        */
-        TInt HandleServerUnblackListIap( const TConnectionId aConnId, 
-                                         TBlacklistCategory  aCategory );
-
-        /**
-        * Handling of unblacklisting all IAPs for certain category.
-        * @since 3.2
         * @param aCategory Either connection lifetime or temporary. 
         */
         void HandleServerUnblackListIap( TBlacklistCategory  aCategory );
@@ -437,9 +440,11 @@
         * Notify each session about IAP availability change.
         * @since 3.1
-        * @param aIapInfo Info about available IAPs 
+        * @param aIapInfo Info about available IAPs
+        * @param aCaller Identifies the calling context 
         */